==> 0.1.4.tar.gz: lib/widget/vgk-range-widget/vgk-range-widget.dart <==
import 'package:flutter/material.dart';
import 'package:step_progress_indicator/step_progress_indicator.dart';
import 'package:vgkprogaming/theme/vgk-shared-theme.dart';

Widget vgkRangeWidget(String key, String value, int precentage) {
  return Column(
    mainAxisAlignment: MainAxisAlignment.center,
    crossAxisAlignment: CrossAxisAlignment.start,
    children: <Widget>[
      Row(children: <Widget>[
        Expanded(
          child: Text(
            key,
            textAlign: TextAlign.left,
            style: VgkprogamingTheme.h4,
          ),
        ),
        Padding(
          padding: const EdgeInsets.only(left: 8),
          child: Text(
            value,
            textAlign: TextAlign.left,
            style: VgkprogamingTheme.h4,
          ),
        )
      ]),
      Padding(
        padding: const EdgeInsets.only(top: 4),
        child: StepProgressIndicator(
          totalSteps: 100,
          currentStep: precentage,
          size: 8,
          padding: 0,
          selectedColor: Colors.yellow,
          unselectedColor: Colors.cyan,
          roundedEdges: Radius.circular(10),
          selectedGradientColor: LinearGradient(
            begin: Alignment.topLeft,
            end: Alignment.bottomRight,
            colors: [
              VgkprogamingTheme.primaryColor,
              VgkprogamingTheme.primaryColor
            ],
          ),
          unselectedGradientColor: LinearGradient(
            begin: Alignment.topLeft,
            end: Alignment.bottomRight,
            colors: [
              VgkprogamingTheme.primaryColor.withOpacity(0.2),
              VgkprogamingTheme.primaryColor.withOpacity(0.2)
            ],
          ),
        ),
      ),
    ],
  );
}

==> 0.9.3.tar.gz: lib/widget/vgk-range-widget/vgk-range-widget.dart <==
import 'package:flutter/material.dart';
import 'package:step_progress_indicator/step_progress_indicator.dart';
import 'package:vgkprogaming/theme/vgk-shared-theme.dart';

Widget vgkRangeWidget(String key, String value, int precentage, primaryColor) {
  return Column(
    mainAxisAlignment: MainAxisAlignment.center,
    crossAxisAlignment: CrossAxisAlignment.start,
    children: <Widget>[
      Row(children: <Widget>[
        Expanded(
          child: Text(
            key,
            textAlign: TextAlign.left,
            style: VgkProGamingTheme.h4(primaryColor),
          ),
        ),
        Padding(
          padding: const EdgeInsets.only(left: 8),
          child: Text(
            value,
            textAlign: TextAlign.left,
            style: VgkProGamingTheme.h4(primaryColor),
          ),
        )
      ]),
      Padding(
        padding: const EdgeInsets.only(top: 4),
        child: StepProgressIndicator(
          totalSteps: 100,
          currentStep: precentage,
          size: 8,
          padding: 0,
          selectedColor: Colors.yellow,
          unselectedColor: Colors.cyan,
          roundedEdges: Radius.circular(10),
          selectedGradientColor: LinearGradient(
            begin: Alignment.topLeft,
            end: Alignment.bottomRight,
            colors: [HexColor(primaryColor), HexColor(primaryColor)],
          ),
          unselectedGradientColor: LinearGradient(
            begin: Alignment.topLeft,
            end: Alignment.bottomRight,
            colors: [
              HexColor(primaryColor).withOpacity(0.2),
              HexColor(primaryColor).withOpacity(0.2)
            ],
          ),
        ),
      ),
    ],
  );
}
